<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateProductDailyWinTimeRequest;
use App\Http\Requests\UpdateProductDailyWinTimeRequest;
use App\Repositories\ProductDailyWinTimeRepository;
use App\Http\Controllers\AppBaseController;
use Illuminate\Http\Request;
use Flash;
use Response;

class ProductDailyWinTimeController extends AppBaseController
{
    /** @var  ProductDailyWinTimeRepository */
    private $productDailyWinTimeRepository;

    public function __construct(ProductDailyWinTimeRepository $productDailyWinTimeRepo)
    {
        $this->productDailyWinTimeRepository = $productDailyWinTimeRepo;
    }

    /**
     * Display a listing of the ProductDailyWinTime.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function index(Request $request)
    {
        $productDailyWinTimes = $this->productDailyWinTimeRepository->paginate(25);

        return view('product_daily_win_times.index')
            ->with('productDailyWinTimes', $productDailyWinTimes);
    }

    /**
     * Show the form for creating a new ProductDailyWinTime.
     *
     * @return Response
     */
    public function create()
    {
        return view('product_daily_win_times.create');
    }

    /**
     * Store a newly created ProductDailyWinTime in storage.
     *
     * @param CreateProductDailyWinTimeRequest $request
     *
     * @return Response
     */
    public function store(CreateProductDailyWinTimeRequest $request)
    {
        $input = $request->all();

        $productDailyWinTime = $this->productDailyWinTimeRepository->create($input);

        Flash::success('Product Daily Win Time saved successfully.');

        return redirect(route('productDailyWinTimes.index'));
    }

    /**
     * Display the specified ProductDailyWinTime.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            Flash::error('Product Daily Win Time not found');

            return redirect(route('productDailyWinTimes.index'));
        }

        return view('product_daily_win_times.show')->with('productDailyWinTime', $productDailyWinTime);
    }

    /**
     * Show the form for editing the specified ProductDailyWinTime.
     *
     * @param int $id
     *
     * @return Response
     */
    public function edit($id)
    {
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            Flash::error('Product Daily Win Time not found');

            return redirect(route('productDailyWinTimes.index'));
        }

        return view('product_daily_win_times.edit')->with('productDailyWinTime', $productDailyWinTime);
    }

    /**
     * Update the specified ProductDailyWinTime in storage.
     *
     * @param int $id
     * @param UpdateProductDailyWinTimeRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateProductDailyWinTimeRequest $request)
    {
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            Flash::error('Product Daily Win Time not found');

            return redirect(route('productDailyWinTimes.index'));
        }

        $productDailyWinTime = $this->productDailyWinTimeRepository->update($request->all(), $id);

        Flash::success('Product Daily Win Time updated successfully.');

        return redirect(route('productDailyWinTimes.index'));
    }

    /**
     * Remove the specified ProductDailyWinTime from storage.
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            Flash::error('Product Daily Win Time not found');

            return redirect(route('productDailyWinTimes.index'));
        }

        $this->productDailyWinTimeRepository->delete($id);

        Flash::success('Product Daily Win Time deleted successfully.');

        return redirect(route('productDailyWinTimes.index'));
    }
}
