<?php namespace Tests\Repositories;

use App\Models\ProductInPromoByDay;
use App\Repositories\ProductInPromoByDayRepository;
use Illuminate\Foundation\Testing\DatabaseTransactions;
use Tests\TestCase;
use Tests\ApiTestTrait;

class ProductInPromoByDayRepositoryTest extends TestCase
{
    use ApiTestTrait, DatabaseTransactions;

    /**
     * @var ProductInPromoByDayRepository
     */
    protected $productInPromoByDayRepo;

    public function setUp() : void
    {
        parent::setUp();
        $this->productInPromoByDayRepo = \App::make(ProductInPromoByDayRepository::class);
    }

    /**
     * @test create
     */
    public function test_create_product_in_promo_by_day()
    {
        $productInPromoByDay = ProductInPromoByDay::factory()->make()->toArray();

        $createdProductInPromoByDay = $this->productInPromoByDayRepo->create($productInPromoByDay);

        $createdProductInPromoByDay = $createdProductInPromoByDay->toArray();
        $this->assertArrayHasKey('id', $createdProductInPromoByDay);
        $this->assertNotNull($createdProductInPromoByDay['id'], 'Created ProductInPromoByDay must have id specified');
        $this->assertNotNull(ProductInPromoByDay::find($createdProductInPromoByDay['id']), 'ProductInPromoByDay with given id must be in DB');
        $this->assertModelData($productInPromoByDay, $createdProductInPromoByDay);
    }

    /**
     * @test read
     */
    public function test_read_product_in_promo_by_day()
    {
        $productInPromoByDay = ProductInPromoByDay::factory()->create();

        $dbProductInPromoByDay = $this->productInPromoByDayRepo->find($productInPromoByDay->id);

        $dbProductInPromoByDay = $dbProductInPromoByDay->toArray();
        $this->assertModelData($productInPromoByDay->toArray(), $dbProductInPromoByDay);
    }

    /**
     * @test update
     */
    public function test_update_product_in_promo_by_day()
    {
        $productInPromoByDay = ProductInPromoByDay::factory()->create();
        $fakeProductInPromoByDay = ProductInPromoByDay::factory()->make()->toArray();

        $updatedProductInPromoByDay = $this->productInPromoByDayRepo->update($fakeProductInPromoByDay, $productInPromoByDay->id);

        $this->assertModelData($fakeProductInPromoByDay, $updatedProductInPromoByDay->toArray());
        $dbProductInPromoByDay = $this->productInPromoByDayRepo->find($productInPromoByDay->id);
        $this->assertModelData($fakeProductInPromoByDay, $dbProductInPromoByDay->toArray());
    }

    /**
     * @test delete
     */
    public function test_delete_product_in_promo_by_day()
    {
        $productInPromoByDay = ProductInPromoByDay::factory()->create();

        $resp = $this->productInPromoByDayRepo->delete($productInPromoByDay->id);

        $this->assertTrue($resp);
        $this->assertNull(ProductInPromoByDay::find($productInPromoByDay->id), 'ProductInPromoByDay should not exist in DB');
    }
}
